@@ -29,7 +29,7 @@ def distill(exc_info=None, num_extra_lines=5, var_depth=2, object_length_limit=D
     returned.update(
         exception=dict(
             type=str(exc_type),
-            value=str(exc_value),
+            value=_safe_str(exc_value),
             vars=_distill_vars(exc_value, var_depth, object_length_limit)
             ),
         traceback=_distill_traceback(exc_tb, num_extra_lines, var_depth, object_length_limit),
@@ -74,8 +74,10 @@ def _distill_vars(vars, max_depth, object_length_limit):
         returned.append(var_dict)
     return returned
 
+_SIMPLE_SEQUENCE_TYPES = set([tuple, list, dict, set, frozenset])
+
 def _is_object_too_long(obj, length_limit):
-    return hasattr(obj, '__len__') and not isinstance(obj, type) and len(obj) > length_limit
+    return type(obj) in _SIMPLE_SEQUENCE_TYPES and len(obj) > length_limit
 
 def _get_vars_items(vars):
     if type(vars) is dict:
@@ -122,3 +124,8 @@ def _safe_repr(obj):
         return repr(obj)
     except:
         return ERROR_STRING
+def _safe_str(obj):
+    try:
+        return str(obj)
+    except:
+        return ERROR_STRING
